@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/bookmarks/content/addBookmark2.js"
+//@line 40 "/usr/obj/i386/mozilla-firefox-2.0.0.2/mozilla/browser/components/bookmarks/content/addBookmark2.js"
 
 /**
  * Add Bookmark Dialog. 
@@ -59,8 +59,9 @@ var gSuggestedKeyword;
 var gRequiredFields = [];
 var gPostData;
 var gArg = window.arguments[0];
+var gResource;
 
-//@line 102 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/bookmarks/content/addBookmark2.js"
+//@line 104 "/usr/obj/i386/mozilla-firefox-2.0.0.2/mozilla/browser/components/bookmarks/content/addBookmark2.js"
 var WSucks;
 
 function Startup()
@@ -68,7 +69,6 @@ function Startup()
   initServices();
   initBMService();
   gName = document.getElementById("name");
-  gRequiredFields.push(gName);
   gKeywordRow = document.getElementById("keywordRow");
   gKeyword = document.getElementById("keyword");
   gExpander = document.getElementById("expander");
@@ -98,7 +98,7 @@ function Startup()
     document.title = strings.getString("addLiveBookmarkTitle");
   }
 
-//@line 140 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/bookmarks/content/addBookmark2.js"
+//@line 141 "/usr/obj/i386/mozilla-firefox-2.0.0.2/mozilla/browser/components/bookmarks/content/addBookmark2.js"
   WSucks = parseInt(gBookmarksTree.getAttribute("height"));
   if (!WSucks)
     WSucks = 150;
@@ -127,8 +127,14 @@ function Startup()
     gSelectedFolder = RDF.GetResource(gMenulist.selectedItem.id);
   }
   setTimeout(initMenulist, 0);
+
+  // Reset the |id| attribute on the toolbar folder attribute to the URI of the
+  // Bookmarks toolbar folder. 
   var btfMenuItem = document.getElementById("btfMenuItem");
-  btfMenuItem.setAttribute("id", BMSVC.getBookmarksToolbarFolder().Value);
+  btfMenuItem.id = BMSVC.getBookmarksToolbarFolder().Value;
+
+  if (MicrosummaryPicker.enabled)
+    MicrosummaryPicker.init();
 } 
 
 function initTitle()
@@ -155,35 +161,52 @@ function onOK()
 {
   RDFC.Init(BMDS, gSelectedFolder);
   
-  var url, rSource;
+  var url;
   var livemarkFeed = gArg.feedURL;
   if (gArg.bBookmarkAllTabs) {
-    rSource = BMDS.createFolder(gName.value);
+    gResource = BMDS.createFolder(gName.value);
     const groups = gArg.objGroup;
     for (var i = 0; i < groups.length; ++i) {
       url = getNormalizedURL(groups[i].url);
       BMDS.createBookmarkInContainer(groups[i].name, url, gKeyword.value, 
                                      groups[i].description, groups[i].charset, 
-                                     gPostData, rSource, -1);
+                                     gPostData, gResource, -1);
     }
   } else if (livemarkFeed != null) {
     url = getNormalizedURL(gArg.url);
-    rSource = BMDS.createLivemark(gName.value, url, livemarkFeed, 
-                                  gArg.description);
+    gResource = BMDS.createLivemark(gName.value, url, livemarkFeed, 
+                                    gArg.description);
   } else {
     url = getNormalizedURL(gArg.url);
-    rSource = BMDS.createBookmark(gName.value, url, gKeyword.value, 
-                                  gArg.description, gArg.charset, 
-                                  gPostData);
+
+    var name = gName.value;
+
+    // If the microsummary picker is enabled, the value of the name field
+    // won't necessarily contain the user-entered name for the bookmark.
+    // But the first item in the microsummary drop-down menu will always
+    // contain the user-entered name, so get the name from there instead.
+    if (MicrosummaryPicker.enabled) {
+      var menuPopup = document.getElementById("microsummaryMenuPopup");
+      name = menuPopup.childNodes[0].getAttribute("label");
+    }
+
+    gResource = BMDS.createBookmark(name, url, gKeyword.value, 
+                                    gArg.description, gArg.charset, 
+                                    gPostData);
   }
 
-  var selection = BookmarksUtils.getSelectionFromResource(rSource);
+  var selection = BookmarksUtils.getSelectionFromResource(gResource);
   var target    = BookmarksUtils.getTargetFromFolder(gSelectedFolder);
   BookmarksUtils.insertAndCheckSelection("newbookmark", selection, target);
-  
-  if (gArg.bWebPanel && rSource) {
+
+  if (MicrosummaryPicker.enabled) {
+    MicrosummaryPicker.commit();
+    MicrosummaryPicker.destroy();
+  }
+
+  if (gArg.bWebPanel && gResource) {
     // Assert that we're a web panel.
-    BMDS.Assert(rSource, RDF.GetResource(gNC_NS+"WebPanel"),
+    BMDS.Assert(gResource, RDF.GetResource(gNC_NS+"WebPanel"),
                 RDF.GetLiteral("true"), true);
   }
   
@@ -194,6 +217,21 @@ function onOK()
   remoteDS.Flush();
 }
 
+function onCancel()
+{
+  // Destroy the microsummary picker controller to prevent memory leaks,
+  // catching exceptions so we don't prevent the dialog from closing.
+  try {
+    if (MicrosummaryPicker.enabled)
+      MicrosummaryPicker.destroy();
+  }
+  catch(e) {
+    Components.utils.reportError(e);
+  }
+
+  return true;
+}
+
 function getNormalizedURL(url)
 {
   // Check to see if the item is a local directory path, and if so, convert
@@ -226,6 +264,14 @@ function selectMenulistFolder(aEvent)
 
 function selectTreeFolder()
 {
+  // If no item is selected, we obviously can't do anything with the selection.
+  // This happens when the bookmarks tree rebuilds, since the rebuild starts
+  // by removing all items from the tree, including the currently selected item,
+  // and removing the selection also triggers the "select" handler which calls
+  // this function.
+  if (gBookmarksTree.currentIndex == -1)
+    return;
+
   var resource = gBookmarksTree.currentResource;
   if (resource == gSelectedFolder)
     return;
@@ -249,7 +295,7 @@ function selectFolder(aFolder)
   var index = gBookmarksTree.currentIndex;
   gBookmarksTree.treeBoxObject.ensureRowIsVisible(index);
   gBookmarksTree.treeBoxObject.view.selection.selectEventsSuppressed = false;
-//@line 291 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/bookmarks/content/addBookmark2.js"
+//@line 338 "/usr/obj/i386/mozilla-firefox-2.0.0.2/mozilla/browser/components/bookmarks/content/addBookmark2.js"
 }
 
 function expandTree()
@@ -263,7 +309,7 @@ function expandTree()
     WSucks = gBookmarksTree.boxObject.height;
   } else {
     document.documentElement.buttons = "accept,cancel,extra2";
-//@line 305 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/bookmarks/content/addBookmark2.js"
+//@line 352 "/usr/obj/i386/mozilla-firefox-2.0.0.2/mozilla/browser/components/bookmarks/content/addBookmark2.js"
     if (!gBookmarksTree.treeBoxObject.view.isContainerOpen(0))
       gBookmarksTree.treeBoxObject.view.toggleOpenState(0);
     selectFolder(gSelectedFolder);
