@@ -1,4 +1,4 @@
-//@line 40 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/bookmarks/content/bookmarksManager.js"
+//@line 40 "/usr/obj/i386/mozilla-firefox-2.0.0.2/mozilla/browser/components/bookmarks/content/bookmarksManager.js"
 
 var gSearchBox;
 
@@ -47,13 +47,17 @@ function Startup()
   document.getElementById("CommandUpdate_Bookmarks").setAttribute("commandupdater","true");
   bookmarksView.focus();
 
-  BMSVC.transactionManager.AddListener(BookmarkEditMenuTxnListener);
+  var bkmkTxnSvc = Components.classes["@mozilla.org/bookmarks/transactionmanager;1"]
+                             .getService(Components.interfaces.nsIBookmarkTransactionManager);
+  bkmkTxnSvc.transactionManager.AddListener(BookmarkEditMenuTxnListener);
 
 }
 
 function Shutdown()
 {
-  BMSVC.transactionManager.RemoveListener(BookmarkEditMenuTxnListener);
+  var bkmkTxnSvc = Components.classes["@mozilla.org/bookmarks/transactionmanager;1"]
+                             .getService(Components.interfaces.nsIBookmarkTransactionManager);
+  bkmkTxnSvc.transactionManager.RemoveListener(BookmarkEditMenuTxnListener);
   // Store current window position and size in window attributes (for persistence).
   var win = document.getElementById("bookmark-window");
   win.setAttribute("x", screenX);
@@ -147,7 +151,7 @@ function onViewMenuSortItemSelected(aEvent)
     break;
   }
 
-  aEvent.preventCapture();
+  aEvent.stopPropagation();
 }  
 
 var gConstructedColumnsMenuItems = false;
@@ -178,7 +182,7 @@ function fillColumnsMenu(aEvent)
     }
   }
   
-  aEvent.preventBubble();
+  aEvent.stopPropagation();
 }
 
 function onViewMenuColumnItemSelected(aEvent)
@@ -189,7 +193,7 @@ function onViewMenuColumnItemSelected(aEvent)
     bookmarksView.toggleColumnVisibility(resource);
   }  
 
-  aEvent.preventBubble();
+  aEvent.stopPropagation();
 }
 
 function onViewSelected(aEvent)
