@@ -1,19 +1,12 @@
-//@line 37 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/preferences/content.js"
-
-
-const kDefaultFontType          = "font.default.%LANG%";
-const kFontNameFmtSerif         = "font.name.serif.%LANG%";
-const kFontNameFmtSansSerif     = "font.name.sans-serif.%LANG%";
-const kFontNameListFmtSerif     = "font.name-list.serif.%LANG%";
-const kFontNameListFmtSansSerif = "font.name-list.sans-serif.%LANG%";
-const kFontSizeFmtVariable      = "font.size.variable.%LANG%";
+//@line 40 "/usr/obj/i386/mozilla-firefox-2.0.0.2/mozilla/browser/components/preferences/content.js"
 
 var gContentPane = {
-  _pane: null,
-  
+
+  /**
+   * Initializes the fonts dropdowns displayed in this pane.
+   */
   init: function ()
   {
-    this._pane = document.getElementById("paneContent");
     this._rebuildFonts();
     var menulist = document.getElementById("defaultFont");
     if (menulist.selectedIndex == -1) {
@@ -21,27 +14,150 @@ var gContentPane = {
       menulist.selectedIndex = 0;
     }
   },
-  
+
+  // UTILITY FUNCTIONS
+
+  /**
+   * Utility function to enable/disable the button specified by aButtonID based
+   * on the value of the Boolean preference specified by aPreferenceID.
+   */  
+  updateButtons: function (aButtonID, aPreferenceID)
+  {
+    var button = document.getElementById(aButtonID);
+    var preference = document.getElementById(aPreferenceID);
+    button.disabled = preference.value != true;
+    return undefined;
+  },
+
+  /**
+   * The exceptions types which may be passed to this._showExceptions().
+   */
+  _exceptionsParams: {
+    popup:   { blockVisible: false, sessionVisible: false, allowVisible: true, prefilledHost: "", permissionType: "popup"   },
+    image:   { blockVisible: true,  sessionVisible: false, allowVisible: true, prefilledHost: "", permissionType: "image"   }
+  },
+
+  /**
+   * Displays the exceptions dialog of the given type, where types map onto the
+   * the fields in this._exceptionsParams.
+   */  
+  _showExceptions: function (aPermissionType)
+  {
+    var bundlePreferences = document.getElementById("bundlePreferences");
+    var params = this._exceptionsParams[aPermissionType];
+    params.windowTitle = bundlePreferences.getString(aPermissionType + "permissionstitle");
+    params.introText = bundlePreferences.getString(aPermissionType + "permissionstext");
+    document.documentElement.openWindow("Browser:Permissions",
+                                        "chrome://browser/content/preferences/permissions.xul",
+                                        "", params);
+  },
+
+  // BEGIN UI CODE
+
+  /*
+   * Preferences:
+   *
+   * dom.disable_open_during_load
+   * - true if popups are blocked by default, false otherwise
+   * permissions.default.image
+   * - an integer:
+   *     1   all images should be loaded,
+   *     2   no images should be loaded,
+   *     3   load only images from the site on which the current page resides
+   *         (i.e., if viewing foo.example.com, foo.example.com/foo.jpg and
+   *         bar.foo.example.com/bar.jpg load but example.com/quux.jpg does not)
+   * javascript.enabled
+   * - true if JavaScript is enabled, false otherwise
+   */
+
+  // POP-UPS
+
+  /**
+   * Displays the popup exceptions dialog where specific site popup preferences
+   * can be set.
+   */
+  showPopupExceptions: function ()
+  {
+    this._showExceptions("popup");
+  },
+
+  // IMAGES
+
+  /**
+   * Converts the value of the permissions.default.image preference into a
+   * Boolean value for use in determining the state of the "load images"
+   * checkbox, returning true if images should be loaded and false otherwise.
+   */
+  readLoadImages: function ()
+  {
+    var pref = document.getElementById("permissions.default.image");
+    return (pref.value == 1 || pref.value == 3);
+  },
+
+  /**
+   * Returns the "load images" preference value which maps to the state of the
+   * preferences UI.
+   */
+  writeLoadImages: function ()
+  { 
+    return (document.getElementById("loadImages").checked) ? 1 : 2;
+  },
+
+  /**
+   * Displays image exception preferences for which websites can and cannot
+   * load images.
+   */
+  showImageExceptions: function ()
+  {
+    this._showExceptions("image");
+  },
+
+  // JAVASCRIPT
+
+  /**
+   * Displays the advanced JavaScript preferences for enabling or disabling
+   * various annoying behaviors.
+   */
+  showAdvancedJS: function ()
+  {
+    document.documentElement.openSubDialog("chrome://browser/content/preferences/advanced-scripts.xul",
+                                           "", null);  
+  },
+
+  // FONTS
+
+  /**
+   * Populates the default font list in UI.
+   */
   _rebuildFonts: function ()
   {
     var langGroupPref = document.getElementById("font.language.group");
-    this._selectLanguageGroup(langGroupPref.value, 
-                              this._readDefaultFontTypeForLanguage(langGroupPref.value) == "serif");
+    this._selectDefaultLanguageGroup(langGroupPref.value,
+                                     this._readDefaultFontTypeForLanguage(langGroupPref.value) == "serif");
   },
-  
-  _selectLanguageGroup: function (aLanguageGroup, aIsSerif)
+
+  /**
+   * 
+   */
+  _selectDefaultLanguageGroup: function (aLanguageGroup, aIsSerif)
   {
+    const kFontNameFmtSerif         = "font.name.serif.%LANG%";
+    const kFontNameFmtSansSerif     = "font.name.sans-serif.%LANG%";
+    const kFontNameListFmtSerif     = "font.name-list.serif.%LANG%";
+    const kFontNameListFmtSansSerif = "font.name-list.sans-serif.%LANG%";
+    const kFontSizeFmtVariable      = "font.size.variable.%LANG%";
+
     var prefs = [{ format   : aIsSerif ? kFontNameFmtSerif : kFontNameFmtSansSerif,
-                   type     : "unichar", 
-                   element  : "defaultFont",      
+                   type     : "unichar",
+                   element  : "defaultFont",
                    fonttype : aIsSerif ? "serif" : "sans-serif" },
                  { format   : aIsSerif ? kFontNameListFmtSerif : kFontNameListFmtSansSerif,
-                   type     : "unichar", 
-                   element  : null,               
+                   type     : "unichar",
+                   element  : null,
                    fonttype : aIsSerif ? "serif" : "sans-serif" },
-                 { format   : kFontSizeFmtVariable,      
-                   type     : "int",     
-                   element  : "defaultFontSize",  
+                 { format   : kFontSizeFmtVariable,
+                   type     : "int",
+                   element  : "defaultFontSize",
                    fonttype : null }];
     var preferences = document.getElementById("contentPreferences");
     for (var i = 0; i < prefs.length; ++i) {
@@ -54,14 +170,14 @@ var gContentPane = {
         preference.setAttribute("type", prefs[i].type);
         preferences.appendChild(preference);
       }
-      
+
       if (!prefs[i].element)
         continue;
-        
+
       var element = document.getElementById(prefs[i].element);
       if (element) {
         element.setAttribute("preference", preference.id);
-      
+
         if (prefs[i].fonttype)
           FontBuilder.buildFontList(aLanguageGroup, prefs[i].fonttype, element);
 
@@ -70,8 +186,13 @@ var gContentPane = {
     }
   },
 
+  /**
+   * Returns the type of the current default font for the language denoted by
+   * aLanguageGroup.
+   */
   _readDefaultFontTypeForLanguage: function (aLanguageGroup)
   {
+    const kDefaultFontType = "font.default.%LANG%";
     var defaultFontTypePref = kDefaultFontType.replace(/%LANG%/, aLanguageGroup);
     var preference = document.getElementById(defaultFontTypePref);
     if (!preference) {
@@ -81,74 +202,40 @@ var gContentPane = {
       preference.setAttribute("type", "string");
       preference.setAttribute("onchange", "gContentPane._rebuildFonts();");
       document.getElementById("contentPreferences").appendChild(preference);
-    }  
+    }
     return preference.value;
   },
 
-  writeEnableImagesPref: function ()
-  { 
-    var enableImages = document.getElementById("enableImages");
-    if (enableImages.checked) {
-      var enableRestricted = document.getElementById("enableRestricted");
-      return enableRestricted.checked ? 3 : 1;
-    }
-    return 2;
-  },
-  
-  readEnableImagesPref: function ()
-  {
-    var pref = document.getElementById("permissions.default.image");
-    var enableRestricted = document.getElementById("enableRestricted");    
-    enableRestricted.disabled = pref.value == 2;
-    return (pref.value == 1 || pref.value == 3);
-  },
-  
-  readEnableRestrictedPref: function ()
-  {
-    var pref = document.getElementById("permissions.default.image");
-    return (pref.value == 3);
-  },
-  
-  _exceptionsParams: {
-    install: { blockVisible: false, sessionVisible: false, allowVisible: true, prefilledHost: "", permissionType: "install" },
-    popup:   { blockVisible: false, sessionVisible: false, allowVisible: true, prefilledHost: "", permissionType: "popup"   },
-    image:   { blockVisible: true,  sessionVisible: false, allowVisible: true, prefilledHost: "", permissionType: "image"   }
-  },
-  
-  showExceptions: function (aPermissionType)
-  {
-    var bundlePreferences = document.getElementById("bundlePreferences");
-    var params = this._exceptionsParams[aPermissionType];
-    params.windowTitle = bundlePreferences.getString(aPermissionType + "permissionstitle");
-    params.introText = bundlePreferences.getString(aPermissionType + "permissionstext");
-    document.documentElement.openWindow("Browser:Permissions",
-                                        "chrome://browser/content/preferences/permissions.xul",
-                                        "", params);
-  },
-  
-  updateButtons: function (aButtonID, aPreferenceID)
-  {
-    var button = document.getElementById(aButtonID);
-    var preference = document.getElementById(aPreferenceID);
-    button.disabled = preference.value != true;
-    return undefined;
-  },
-  
-  showAdvancedJS: function ()
-  {
-    document.documentElement.openSubDialog("chrome://browser/content/preferences/advanced-scripts.xul",
-                                           "", null);  
-  },
-
-  showFonts: function ()
+  /**
+   * Displays the fonts dialog, where web page font names and sizes can be
+   * configured.
+   */  
+  configureFonts: function ()
   {
     document.documentElement.openSubDialog("chrome://browser/content/preferences/fonts.xul",
-                                           "", null);  
+                                           "", null);
   },
 
-  showColors: function ()
+  /**
+   * Displays the colors dialog, where default web page/link/etc. colors can be
+   * configured.
+   */
+  configureColors: function ()
   {
     document.documentElement.openSubDialog("chrome://browser/content/preferences/colors.xul",
                                            "", null);  
+  },
+
+  // FILE TYPES
+
+  /**
+   * Displays the file type configuration dialog.
+   */
+  configureFileTypes: function ()
+  {
+    document.documentElement.openWindow("Preferences:DownloadActions",
+                                        "chrome://browser/content/preferences/downloadactions.xul",
+                                        "", null);
   }
+
 };
