@@ -1,4 +1,4 @@
-//@line 36 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/preferences/cookies.js"
+//@line 38 "/usr/obj/i386/mozilla-firefox-2.0.0.2/mozilla/browser/components/preferences/cookies.js"
 
 const nsICookie = Components.interfaces.nsICookie;
 
@@ -151,7 +151,7 @@ var gCookiesWindow = {
     this._view._rowCount += rowCountImpact;
     this._tree.treeBoxObject.rowCountChanged(oldRowCount - 1, rowCountImpact);
 
-    document.getElementById("removeAllCookies").disabled = this._view._filtered || (this._view.rowCount == 0);
+    document.getElementById("removeAllCookies").disabled = this._view._filtered;
   },
   
   _view: {
@@ -478,9 +478,7 @@ var gCookiesWindow = {
   _updateCookieData: function (aItem)
   {
     var seln = this._view.selection;
-    var ids = ["nameLabel", "name", "valueLabel", "value", "isDomain", "host", 
-               "pathLabel", "path", "isSecureLabel", "isSecure", "expiresLabel", 
-               "expires"];
+    var ids = ["name", "value", "host", "path", "isSecure", "expires"];
     var properties;
     
     if (aItem && !aItem.container && seln.count > 0) {
@@ -537,13 +535,13 @@ var gCookiesWindow = {
     var stringKey = selectedCookieCount == 1 ? "removeCookie" : "removeCookies";
     document.getElementById("removeCookie").label = this._bundle.getString(stringKey);
     
-    document.getElementById("removeAllCookies").disabled = this._view._filtered || (this._view.rowCount == 0);
+    document.getElementById("removeAllCookies").disabled = this._view._filtered;
     document.getElementById("removeCookie").disabled = !(seln.count > 0);
   },
   
   deleteCookie: function () 
   { 
-//@line 628 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/preferences/cookies.js"
+//@line 628 "/usr/obj/i386/mozilla-firefox-2.0.0.2/mozilla/browser/components/preferences/cookies.js"
     var seln = this._view.selection;
     var tbo = this._tree.treeBoxObject;
     
@@ -712,6 +710,7 @@ var gCookiesWindow = {
 
     document.getElementById("cookiesIntro").value = this._bundle.getString("cookiesAll");
     document.getElementById("clearFilter").disabled = true;
+    document.getElementById("filter").focus();
   },
   
   _cookieMatchesFilter: function (aCookie)
