@@ -1,4 +1,4 @@
-//@line 37 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/preferences/downloadactions.js"
+//@line 38 "/usr/obj/ports/mozilla-firefox-2.0.0.2/mozilla/browser/components/preferences/downloadactions.js"
 
 const kPluginHandlerContractID = "@mozilla.org/content/plugin/document-loader-factory;1";
 const kDisabledPluginTypesPref = "plugin.disable_full_page_plugin_for_types";
@@ -246,13 +246,11 @@ var gDownloadActionsWindow = {
   
   _getDisplayNameForFile: function (aFile)
   {
-//@line 288 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/preferences/downloadactions.js"
-    // XXXben - Read the bundle name on OS X.
+//@line 304 "/usr/obj/ports/mozilla-firefox-2.0.0.2/mozilla/browser/components/preferences/downloadactions.js"
     var ios = Components.classes["@mozilla.org/network/io-service;1"]
                         .getService(Components.interfaces.nsIIOService);
     var url = ios.newFileURI(aFile).QueryInterface(Components.interfaces.nsIURL);
     return url.fileName;
-//@line 294 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/preferences/downloadactions.js"
   },  
   
   _loadMIMERegistryData: function ()
@@ -727,6 +725,7 @@ var gDownloadActionsWindow = {
 
     document.getElementById("actionsIntro").value = this._bundle.getString("actionsAll");
     document.getElementById("clearFilter").disabled = true;
+    document.getElementById("filter").focus();
   },
   
   _actionMatchesFilter: function (aAction)
