@@ -1,4 +1,4 @@
-//@line 38 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/preferences/languages.js"
+//@line 40 "/usr/obj/ports/mozilla-firefox-2.0.0.2/mozilla/browser/components/preferences/languages.js"
 
 var gLanguagesDialog = {
 
@@ -141,9 +141,11 @@ var gLanguagesDialog = {
       this._acceptLanguages[languages[i]] = true;
     }
 
-    if (this._activeLanguages.childNodes.length > 0) 
+    if (this._activeLanguages.childNodes.length > 0) {
+      this._activeLanguages.ensureIndexIsVisible(selectedIndex);
       this._activeLanguages.selectedIndex = selectedIndex;
-    
+    }
+
     return undefined;
   },
   
