@@ -1,4 +1,4 @@
-//@line 37 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/base/content/sanitize.js"
+//@line 39 "/usr/obj/ports/mozilla-firefox-2.0.0.2/mozilla/browser/base/content/sanitize.js"
 
 function Sanitizer() {}
 Sanitizer.prototype = {
@@ -61,50 +61,9 @@ Sanitizer.prototype = {
         const ci = Components.interfaces;
         var cacheService = cc["@mozilla.org/network/cache-service;1"]
                              .getService(ci.nsICacheService);
-
-        // Here we play dirty, trying to brutally wipe out all the cache files 
-        // even if the disk cache device has gone away (if it is still with us,
-        // our removal attempt will fail because the directory is locked,
-        // and we fall back to the "nice" way below)
-        
-        var cacheDir;
-        // Look at nsCacheProfilePrefObserver::ReadPrefs()
-        // and nsDiskCacheDevice::SetCacheParentDirectory()
-        // for details on how we guess the cache directory
         try {
-          cacheDir = cc["@mozilla.org/preferences-service;1"]
-                       .getService(ci.nsIPrefBranch)
-                       .getComplexValue("browser.cache.disk.parent_directory",
-                                        ci.nsILocalFile);
-        } catch(er) {
-          const dirServ = cc["@mozilla.org/file/directory_service;1"]
-                            .getService(ci.nsIProperties);
-          try {
-            cacheDir = dirServ.get("cachePDir",ci.nsILocalFile);
-          } catch(er) {
-            cacheDir = dirServ.get("ProfLD",ci.nsILocalFile);
-          }
-        }
-        
-        if (cacheDir) {
-          // Here we try to prevent the "phantom Cache.Trash" issue
-          // reported in bug #296256
-          cacheDir.append("Cache.Trash");
-          try {
-            cacheDir.remove(true);
-          } catch(er) {}
-          cacheDir = cacheDir.parent;
-          cacheDir.append("Cache");
-          try {
-           cacheDir.remove(true);
-          } catch(er) {}
-        }
-        
-        try {
-          // The "nice" way
           cacheService.evictEntries(ci.nsICache.STORE_ANYWHERE);
         } catch(er) {}
-        
       },
       
       get canClear()
@@ -123,9 +82,7 @@ Sanitizer.prototype = {
       
       get canClear()
       {
-        var cookieMgr = Components.classes["@mozilla.org/cookiemanager;1"]
-                                  .getService(Components.interfaces.nsICookieManager);
-        return cookieMgr.enumerator.hasMoreElements();
+        return true;
       }
     },
     
@@ -146,25 +103,38 @@ Sanitizer.prototype = {
       
       get canClear()
       {
-        var globalHistory = Components.classes["@mozilla.org/browser/global-history;2"]
-                                      .getService(Components.interfaces.nsIBrowserHistory);
-        return globalHistory.count != 0;
+        // bug 347231: Always allow clearing history due to dependencies on
+        // the browser:purge-session-history notification. (like error console)
+        return true;
       }
     },
     
     formdata: {
       clear: function ()
       {
+        //Clear undo history of all searchBars
+        var windowManager = Components.classes['@mozilla.org/appshell/window-mediator;1'].getService();
+        var windowManagerInterface = windowManager.QueryInterface(Components.interfaces.nsIWindowMediator);
+        var windows = windowManagerInterface.getEnumerator("navigator:browser");
+        while (windows.hasMoreElements()) {
+          var searchBar = windows.getNext().document.getElementById("searchbar");
+          if (searchBar) {
+            searchBar.value = "";
+            searchBar.textbox.editor.enableUndo(false);
+            searchBar.textbox.editor.enableUndo(true);
+          }
+        }
+
         var formHistory = Components.classes["@mozilla.org/satchel/form-history;1"]
-                                    .getService(Components.interfaces.nsIFormHistory);
+                                    .getService(Components.interfaces.nsIFormHistory2);
         formHistory.removeAllEntries();
       },
       
       get canClear()
       {
         var formHistory = Components.classes["@mozilla.org/satchel/form-history;1"]
-                                    .getService(Components.interfaces.nsIFormHistory);
-        return formHistory.rowCount != 0;
+                                    .getService(Components.interfaces.nsIFormHistory2);
+        return formHistory.hasEntries;
       }
     },
     
@@ -252,9 +222,9 @@ Sanitizer.showUI = function(aParentWindow)
 {
   var ww = Components.classes["@mozilla.org/embedcomp/window-watcher;1"]
                      .getService(Components.interfaces.nsIWindowWatcher);
-//@line 293 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/base/content/sanitize.js"
+//@line 265 "/usr/obj/ports/mozilla-firefox-2.0.0.2/mozilla/browser/base/content/sanitize.js"
   ww.openWindow(aParentWindow,
-//@line 295 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/base/content/sanitize.js"
+//@line 267 "/usr/obj/ports/mozilla-firefox-2.0.0.2/mozilla/browser/base/content/sanitize.js"
                 "chrome://browser/content/sanitize.xul",
                 "Sanitize",
                 "chrome,titlebar,centerscreen,modal",
