@@ -60,8 +60,9 @@ const nsIWindowMediator      = Components.interfaces.nsIWindowMediator;
 const nsIWindowWatcher       = Components.interfaces.nsIWindowWatcher;
 const nsICategoryManager     = Components.interfaces.nsICategoryManager;
 const nsIWebNavigationInfo   = Components.interfaces.nsIWebNavigationInfo;
+const nsIBrowserSearchService = Components.interfaces.nsIBrowserSearchService;
 
-const NS_BINDING_ABORTED = 0x80020006;
+const NS_BINDING_ABORTED = 0x804b0002;
 const NS_ERROR_WONT_HANDLE_CONTENT = 0x805d0001;
 const NS_ERROR_ABORT = Components.results.NS_ERROR_ABORT;
 
@@ -114,16 +115,53 @@ function needHomepageOverride(prefb) {
   }
 
   if (savedmstone == "ignore")
-    return false;
+    return 0;
 
   var mstone = Components.classes["@mozilla.org/network/protocol;1?name=http"]
                          .getService(nsIHttpProtocolHandler).misc;
 
-  if (mstone == savedmstone)
-    return false;
+  if (mstone != savedmstone) {
+    prefb.setCharPref("browser.startup.homepage_override.mstone", mstone);
+    // Return 1 if true if the pref didn't exist (i.e. new profile) or 2 for an upgrade
+    return (savedmstone ? 2 : 1);
+  }
+  
+  // Return 0 if not a new profile and not an upgrade
+  return 0;
+}
 
-  prefb.setCharPref("browser.startup.homepage_override.mstone", mstone);
-  return true;
+// Copies a pref override file into the user's profile pref-override folder,
+// and then tells the pref service to reload it's default prefs.
+function copyPrefOverride() {
+  try {
+    var fileLocator = Components.classes["@mozilla.org/file/directory_service;1"]
+                                .getService(Components.interfaces.nsIProperties);
+    const NS_APP_EXISTING_PREF_OVERRIDE = "ExistingPrefOverride";
+    var prefOverride = fileLocator.get(NS_APP_EXISTING_PREF_OVERRIDE,
+                                       Components.interfaces.nsIFile);
+    if (!prefOverride.exists())
+      return; // nothing to do
+
+    const NS_APP_PREFS_OVERRIDE_DIR     = "PrefDOverride";
+    var prefOverridesDir = fileLocator.get(NS_APP_PREFS_OVERRIDE_DIR,
+                                           Components.interfaces.nsIFile);
+
+    // Check for any existing pref overrides, and remove them if present
+    var existingPrefOverridesFile = prefOverridesDir.clone();
+    existingPrefOverridesFile.append(prefOverride.leafName);
+    if (existingPrefOverridesFile.exists())
+      existingPrefOverridesFile.remove(false);
+
+    prefOverride.copyTo(prefOverridesDir, null);
+
+    // Now that we've installed the new-profile pref override file,
+    // re-read the default prefs.
+    var prefSvcObs = Components.classes["@mozilla.org/preferences-service;1"]
+                               .getService(Components.interfaces.nsIObserver);
+    prefSvcObs.observe(null, "reload-default-prefs", null);
+  } catch (ex) {
+    Components.utils.reportError(ex);
+  }
 }
 
 function openWindow(parent, url, target, features, args) {
@@ -157,14 +195,14 @@ function getMostRecentWindow(aType) {
   return wm.getMostRecentWindow(aType);
 }
 
-//@line 165 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 203 "/usr/obj/ports/mozilla-firefox-2.0.0.2/mozilla/browser/components/nsBrowserContentHandler.js"
 
 // this returns the most recent non-popup browser window
 function getMostRecentBrowserWindow() {
   var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                      .getService(Components.interfaces.nsIWindowMediator);
 
-//@line 172 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 210 "/usr/obj/ports/mozilla-firefox-2.0.0.2/mozilla/browser/components/nsBrowserContentHandler.js"
   var win = wm.getMostRecentWindow("navigator:browser", true);
 
   // if we're lucky, this isn't a popup, and we can just return this
@@ -177,11 +215,43 @@ function getMostRecentBrowserWindow() {
         win = nextWin;
     }
   }
-//@line 197 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 235 "/usr/obj/ports/mozilla-firefox-2.0.0.2/mozilla/browser/components/nsBrowserContentHandler.js"
 
   return win;
 }
 
+function doSearch(searchTerm, cmdLine) {
+  var ss = Components.classes["@mozilla.org/browser/search-service;1"]
+                     .getService(nsIBrowserSearchService);
+
+  var submission = ss.defaultEngine.getSubmission(searchTerm, null);
+
+  // fill our nsISupportsArray with uri-as-wstring, null, null, postData
+  var sa = Components.classes["@mozilla.org/supports-array;1"]
+                     .createInstance(Components.interfaces.nsISupportsArray);
+
+  var wuri = Components.classes["@mozilla.org/supports-string;1"]
+                       .createInstance(Components.interfaces.nsISupportsString);
+  wuri.data = submission.uri.spec;
+
+  sa.AppendElement(wuri);
+  sa.AppendElement(null);
+  sa.AppendElement(null);
+  sa.AppendElement(submission.postData);
+
+  // XXXbsmedberg: use handURIToExistingBrowser to obey tabbed-browsing
+  // preferences, but need nsIBrowserDOMWindow extensions
+
+  var wwatch = Components.classes["@mozilla.org/embedcomp/window-watcher;1"]
+                         .getService(nsIWindowWatcher);
+
+  return wwatch.openWindow(null, nsBrowserContentHandler.chromeURL,
+                           "_blank",
+                           "chrome,dialog=no,all" +
+                             nsBrowserContentHandler.getFeatures(cmdLine),
+                           sa);
+}
+
 var nsBrowserContentHandler = {
   /* helper functions */
 
@@ -345,6 +415,14 @@ var nsBrowserContentHandler = {
     }
     if (cmdLine.handleFlag("silent", false))
       cmdLine.preventDefault = true;
+
+    var searchParam = cmdLine.handleFlagWithParam("search", false);
+    if (searchParam) {
+      doSearch(searchParam, cmdLine);
+      cmdLine.preventDefault = true;
+    }
+
+//@line 454 "/usr/obj/ports/mozilla-firefox-2.0.0.2/mozilla/browser/components/nsBrowserContentHandler.js"
   },
 
   helpInfo : "  -browser            Open a browser window.\n",
@@ -354,29 +432,46 @@ var nsBrowserContentHandler = {
   get defaultArgs() {
     var prefb = Components.classes["@mozilla.org/preferences-service;1"]
                           .getService(nsIPrefBranch);
+    var formatter = Components.classes["@mozilla.org/toolkit/URLFormatterService;1"]
+                              .getService(Components.interfaces.nsIURLFormatter);
 
-    if (needHomepageOverride(prefb)) {
-      try {
-        return prefb.getComplexValue("startup.homepage_override_url",
-                                     nsIPrefLocalizedString).data;
-      }
-      catch (e) {
-      }
-    }
-
+    var pagesToLoad = "";
+    var overrideState = needHomepageOverride(prefb);
     try {
-      var choice = prefb.getIntPref("browser.startup.page");
-      if (choice == 1)
-        return this.startPage;
+      if (overrideState == 1) {
+        // New profile.
+        pagesToLoad = formatter.formatURLPref("startup.homepage_welcome_url");
+      }
+      else if (overrideState == 2) {
+        // Existing profile.
+        copyPrefOverride();
 
-      if (choice == 2)
-        return Components.classes["@mozilla.org/browser/global-history;2"]
-                         .getService(nsIBrowserHistory).lastPageVisited;
+        pagesToLoad = formatter.formatURLPref("startup.homepage_override_url");
+      }
     }
     catch (e) {
     }
 
-    return "about:blank";
+    var startpage = "";
+    try {
+      var choice = prefb.getIntPref("browser.startup.page");
+      if (choice == 1)
+        startpage = this.startPage;
+
+      if (choice == 2)
+        startpage = Components.classes["@mozilla.org/browser/global-history;2"]
+                              .getService(nsIBrowserHistory).lastPageVisited;
+    }
+    catch (e) {
+    }
+
+    if (startpage == "about:blank")
+      startpage = "";
+
+    if (pagesToLoad && startpage) pagesToLoad += "|";
+    pagesToLoad += startpage;
+
+    return (pagesToLoad ?  pagesToLoad : "about:blank");
   },
 
   get startPage() {
@@ -514,23 +609,49 @@ var nsDefaultCommandLineHandler = {
     return this;
   },
 
+  // List of uri's that were passed via the command line without the app
+  // running and have already been handled. This is compared against uri's
+  // opened using DDE on Win32 so we only open one of the requests.
+  _handledURIs: [ ],
+//@line 647 "/usr/obj/ports/mozilla-firefox-2.0.0.2/mozilla/browser/components/nsBrowserContentHandler.js"
+
   /* nsICommandLineHandler */
   handle : function dch_handle(cmdLine) {
     var urilist = [];
 
+//@line 673 "/usr/obj/ports/mozilla-firefox-2.0.0.2/mozilla/browser/components/nsBrowserContentHandler.js"
+
     try {
       var ar;
       while ((ar = cmdLine.handleFlagWithParam("url", false))) {
-        urilist.push(resolveURIInternal(cmdLine, ar));
+        var found = false;
+        var uri = resolveURIInternal(cmdLine, ar);
+        // count will never be greater than zero except on Win32.
+        var count = this._handledURIs.length;
+        for (var i = 0; i < count; ++i) {
+          if (this._handledURIs[i].spec == uri.spec) {
+            this._handledURIs.splice(i, 1);
+            found = true;
+            cmdLine.preventDefault = true;
+            break;
+          }
+        }
+        if (!found) {
+          urilist.push(uri);
+          // The requestpending command line flag is only used on Win32.
+          if (cmdLine.handleFlag("requestpending", false) &&
+              cmdLine.state == nsICommandLine.STATE_INITIAL_LAUNCH)
+            this._handledURIs.push(uri)
+        }
       }
     }
     catch (e) {
       Components.utils.reportError(e);
     }
 
-    var count = cmdLine.length;
+    count = cmdLine.length;
 
-    for (var i = 0; i < count; ++i) {
+    for (i = 0; i < count; ++i) {
       var curarg = cmdLine.getArgument(i);
       if (curarg.match(/^-/)) {
         Components.utils.reportError("Warning: unrecognized command line flag " + curarg + "\n");
@@ -561,7 +682,7 @@ var nsDefaultCommandLineHandler = {
       }
 
       var speclist = [];
-      for (var uri in urilist) {
+      for (uri in urilist) {
         if (shouldLoadURI(urilist[uri]))
           speclist.push(urilist[uri].spec);
       }
@@ -639,18 +760,18 @@ var Module = {
 
     function registerType(contentType) {
       compReg.registerFactoryLocation( bch_CID,
-				       "Browser Cmdline Handler",
-				       CONTRACTID_PREFIX + contentType,
-				       fileSpec,
-				       location,
-				       type );
+                                       "Browser Cmdline Handler",
+                                       CONTRACTID_PREFIX + contentType,
+                                       fileSpec,
+                                       location,
+                                       type );
     }
 
     registerType("text/html");
     registerType("application/vnd.mozilla.xul+xml");
-//@line 668 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 823 "/usr/obj/ports/mozilla-firefox-2.0.0.2/mozilla/browser/components/nsBrowserContentHandler.js"
     registerType("image/svg+xml");
-//@line 670 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 825 "/usr/obj/ports/mozilla-firefox-2.0.0.2/mozilla/browser/components/nsBrowserContentHandler.js"
     registerType("text/rdf");
     registerType("text/xml");
     registerType("application/xhtml+xml");
