@@ -1,4 +1,4 @@
-//@line 44 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/components/filepicker/content/filepicker.js"
+//@line 44 "/usr/obj/i386/mozilla-firefox-2.0.0.2/mozilla/toolkit/components/filepicker/content/filepicker.js"
 
 const nsIFilePicker       = Components.interfaces.nsIFilePicker;
 const nsIDirectoryServiceProvider = Components.interfaces.nsIDirectoryServiceProvider;
@@ -711,6 +711,7 @@ function gotoDirectory(directory) {
     textInput.value = "";
   }
   textInput.focus();
+  textInput.setAttribute("autocompletesearchparam", directory.path);
   sfile = directory;
 }
 
