@@ -1,4 +1,4 @@
-//@line 41 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/components/printing/content/printUtils.js"
+//@line 41 "/usr/obj/i386/mozilla-firefox-2.0.0.2/mozilla/toolkit/components/printing/content/printUtils.js"
 
 var  XUL_NS = "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
 
@@ -193,7 +193,7 @@ var PrintUtils = {
     printPreviewTB.setAttribute("printpreview", true);
     printPreviewTB.setAttribute("id", "print-preview-toolbar");
 
-//@line 236 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/components/printing/content/printUtils.js"
+//@line 236 "/usr/obj/i386/mozilla-firefox-2.0.0.2/mozilla/toolkit/components/printing/content/printUtils.js"
     getBrowser().parentNode.insertBefore(printPreviewTB, getBrowser());
 
     // Tab browser...
@@ -201,7 +201,7 @@ var PrintUtils = {
       this._chromeState.hadTabStrip = getBrowser().getStripVisibility();
       getBrowser().setStripVisibilityTo(false);
     }
-//@line 244 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/components/printing/content/printUtils.js"
+//@line 244 "/usr/obj/i386/mozilla-firefox-2.0.0.2/mozilla/toolkit/components/printing/content/printUtils.js"
 
     // copy the window close handler
     if (document.documentElement.hasAttribute("onclose"))
@@ -226,7 +226,7 @@ var PrintUtils = {
   {
     window.removeEventListener("keypress", this.onKeyPressPP, true);
 
-//@line 272 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/components/printing/content/printUtils.js"
+//@line 272 "/usr/obj/i386/mozilla-firefox-2.0.0.2/mozilla/toolkit/components/printing/content/printUtils.js"
 
     // restore the old close handler
     document.documentElement.setAttribute("onclose", this._closeHandlerPP);
@@ -262,8 +262,17 @@ var PrintUtils = {
     var isModif = aEvent.ctrlKey || aEvent.metaKey;
     // ESC and Ctrl-W exits the PP
     if (aEvent.keyCode == aEvent.DOM_VK_ESCAPE || isModif &&
-        (aEvent.charCode == closeKey || aEvent.charCode == closeKey + 32))
+        (aEvent.charCode == closeKey || aEvent.charCode == closeKey + 32)) {
       PrintUtils.exitPrintPreview();
+    }
+    else if (isModif) {
+      var printPreviewTB = document.getElementById("print-preview-toolbar");
+      var printKey = document.getElementById("printKb").getAttribute("key").toUpperCase();
+      var pressedKey = String.fromCharCode(aEvent.charCode).toUpperCase();
+      if (printKey == pressedKey) {
+	  PrintUtils.print();
+      }
+    }
     // cancel shortkeys
     if (isModif) {
       aEvent.preventDefault();
