@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/components/viewsource/content/viewSource.js"
+//@line 39 "/usr/obj/i386/mozilla-firefox-2.0.0.2/mozilla/toolkit/components/viewsource/content/viewSource.js"
 
 const pageLoaderIface = Components.interfaces.nsIWebPageDescriptor;
 const nsISelectionPrivate = Components.interfaces.nsISelectionPrivate;
@@ -31,16 +31,12 @@ function onLoadViewSource()
 {
   viewSource(window.arguments[0]);
   document.commandDispatcher.focusedWindow = content;
-//@line 72 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/components/viewsource/content/viewSource.js"
-  initFindBar();
-//@line 74 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/components/viewsource/content/viewSource.js"
+  gFindBar.initFindBar();
 }
 
 function onUnloadViewSource()
 {
-//@line 79 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/components/viewsource/content/viewSource.js"
-  uninitFindBar();
-//@line 81 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/components/viewsource/content/viewSource.js"
+  gFindBar.uninitFindBar();
 }
 
 function getBrowser()
@@ -347,9 +343,8 @@ function goToLine(line)
 
   gLastLineFound = line;
 
-  //pch: don't update the status bar for now
-  //document.getElementById("statusbar-line-col").label = getViewSourceBundle()
-  //    .getFormattedString("statusBarLineCol", [line, 1]);
+  document.getElementById("statusbar-line-col").label =
+    getViewSourceBundle().getFormattedString("statusBarLineCol", [line, 1]);
 
   return true;
 }
@@ -382,8 +377,6 @@ function updateStatusBar()
   findLocation(null, -1, 
       selection.focusNode, selection.focusOffset, interlinePosition, result);
 
-  //pch no status bar for now
-  return;
   statusBarField.label = getViewSourceBundle()
       .getFormattedString("statusBarLineCol", [result.line, result.col]);
 }
