@@ -1,4 +1,4 @@
-//@line 37 "/usr/obj/ports/mozilla-firefox-1.5.0.12/mozilla/toolkit/mozapps/xpinstall/content/xpinstallConfirm.js"
+//@line 37 "/usr/obj/i386/mozilla-firefox-2.0.0.2/mozilla/toolkit/mozapps/xpinstall/content/xpinstallConfirm.js"
 
 var XPInstallConfirm = 
 { 
@@ -21,6 +21,14 @@ XPInstallConfirm.init = function ()
   
   this._param.SetInt(0, 1); // The default return value is "Cancel"
   
+  var _installCountdownLength = 5;
+  try {
+    var prefs = Components.classes["@mozilla.org/preferences-service;1"]
+                          .getService(Components.interfaces.nsIPrefBranch);
+    var delay_in_milliseconds = prefs.getIntPref("security.dialog_enable_delay");
+    _installCountdownLength = Math.round(delay_in_milliseconds / 500);
+  } catch (ex) { }
+  
   var itemList = document.getElementById("itemList");
   
   var numItemsToInstall = this._param.GetInt(1);
@@ -38,9 +46,9 @@ XPInstallConfirm.init = function ()
     installItem.signed = cert ? "true" : "false";
   }
   
-  var introString = bundle.getString("itemWarningIntroSingle");
+  var introString = bundle.getString("itemWarnIntroSingle");
   if (numItemsToInstall > 4)
-    introString = bundle.getFormattedString("itemWarningIntroMultiple", [numItemsToInstall / 4]);
+    introString = bundle.getFormattedString("itemWarnIntroMultiple", [numItemsToInstall / 4]);
   if (this._param.objects && this._param.objects.length)
     introString = this._param.objects.queryElementAt(0, Components.interfaces.nsISupportsString).data;
   var textNode = document.createTextNode(introString);
@@ -51,7 +59,6 @@ XPInstallConfirm.init = function ()
   
   var okButton = document.documentElement.getButton("accept");
   okButton.focus();
-  okButton.disabled = true;
 
   function okButtonCountdown() {
     _installCountdown -= 1;
@@ -79,7 +86,7 @@ XPInstallConfirm.init = function ()
     if (_focused)
       return;
 
-    _installCountdown = 5;
+    _installCountdown = _installCountdownLength;
     _installCountdownInterval = setInterval(okButtonCountdown, 500);
     okButton.label = bundle.getFormattedString("installButtonDisabledLabel", [_installCountdown]);
     _focused = true;
@@ -101,7 +108,7 @@ XPInstallConfirm.init = function ()
 
     // Set _installCountdown to the inital value set in setWidgetsAfterFocus
     // plus 1 so when the window is focused there is immediate ui feedback.
-    _installCountdown = 6;
+    _installCountdown = _installCountdownLength + 1;
     okButton.label = bundle.getFormattedString("installButtonDisabledLabel", [_installCountdown]);
     okButton.disabled = true;
     clearInterval(_installCountdownInterval);
@@ -114,11 +121,16 @@ XPInstallConfirm.init = function ()
     window.removeEventListener("unload", myUnload, false);
   }
 
-  document.addEventListener("focus", myfocus, true);
-  document.addEventListener("blur", myblur, true);
-  window.addEventListener("unload", myUnload, false);
+  if (_installCountdownLength > 0) {
+    document.addEventListener("focus", myfocus, true);
+    document.addEventListener("blur", myblur, true);
+    window.addEventListener("unload", myUnload, false);
 
-  setWidgetsAfterFocus();
+    okButton.disabled = true;
+    setWidgetsAfterFocus();
+  }
+  else
+    okButton.label = bundle.getString("installButtonLabel");
 }
 
 XPInstallConfirm.onOK = function ()
